pub trait NumberT: NumberT { }👎Deprecated: use
humat instead, this crate will be removed in the future.Expand description
Sealed trait for number that can be formatted, including:
u8u16u32u64u128i8i16i32i64i128f32f64
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.